@@ -28,6 +28,7 @@ class Dataset:
     licence = "-"
     documentation = "-"
     citation = "-"
+    terms_of_use = None
 
     _source = None
 
@@ -50,6 +51,9 @@ class Dataset:
     def __getitem__(self, n):
         return self.source[n]
 
+    def sel(self, *args, **kwargs):
+        return self.source.sel(*args, **kwargs)
+
     def to_numpy(self, *args, **kwargs):
         import numpy as np
 
@@ -70,8 +74,17 @@ class Dataset:
     def annotate(self, data, **kargs):
         return annotate(data, self, **kargs)
 
-    def check_parameter(self, name, value, *values):
-        pass
+    def read_csv_options(self, *args, **kwargs):
+        return {}
+
+    def read_zarr_options(self, *args, **kwargs):
+        return {}
+
+    def cfgrib_options(self, *args, **kwargs):
+        return {}
+
+    def post_xarray_open_dataset_hook(self, ds, *args, **kwargs):
+        return ds
 
 
 def _module_callback(plugin):
@@ -125,6 +138,8 @@ class DatasetMaker:
 
 dataset = DatasetMaker()
 
+TERMS_OF_USE_SHOWN = set()
+
 
 def load_dataset(name, *args, **kwargs):
     try:
@@ -134,5 +149,12 @@ def load_dataset(name, *args, **kwargs):
         return ds
     except Exception:
         ds = dataset(name)
+
+        if name not in TERMS_OF_USE_SHOWN:
+            if ds.terms_of_use is not None:
+                print(ds.terms_of_use)
+            TERMS_OF_USE_SHOWN.add(name)
+
         ds._load(*args, **kwargs)
+
         return ds
