@@ -10,7 +10,7 @@
 import logging
 import yaml
 
-from climetlab.core.bbox import BoundingBox
+from climetlab.utils.bbox import BoundingBox
 from climetlab.core.caching import temp_file
 from climetlab.core.ipython import SVG, Image
 from climetlab.core.metadata import annotation
@@ -170,7 +170,8 @@ class Driver:
 
     def plot_xarray(self, ds, variable: str, dimensions: dict = None):
         tmp = self.temporary_file(".nc")
-        ds.to_netcdf(tmp)
+        field = ds[variable].isel({} if dimensions is None else dimensions)
+        field.to_netcdf(tmp)
         self.plot_netcdf(tmp, variable, {} if dimensions is None else dimensions)
 
     def plot_csv(self, path: str, variable: str):
