@@ -55,6 +55,7 @@ class DataSource:
     home_page = "-"
     licence = "-"
     documentation = "-"
+    citation = "-"
 
     _dataset = None
 
@@ -77,12 +78,31 @@ class DataSource:
 
     @dataset.setter
     def dataset(self, dataset):
-        self._dataset = weakref.ref(dataset)
+        self._set_dataset(weakref.ref(dataset))
+
+    def _set_dataset(self, dataset):
+        self._dataset = dataset
 
     def _repr_html_(self):
         return table(self)
 
-    def read_csv_options(self):
+    def read_csv_options(self, *args, **kwargs):
         if self.dataset is None:
             return {}
-        return self.dataset.read_csv_options()
+        return self.dataset.read_csv_options(*args, **kwargs)
+
+    def read_zarr_options(self, *args, **kwargs):
+        if self.dataset is None:
+            return {}
+        return self.dataset.read_zarr_options(*args, **kwargs)
+
+    def cfgrib_options(self, *args, **kwargs):
+        if self.dataset is None:
+            return {}
+        return self.dataset.cfgrib_options(*args, **kwargs)
+
+    def post_xarray_open_dataset_hook(self, ds, *args, **kwargs):
+        if self.dataset is None:
+            # print(f'from {self} no self.dataset {self.dataset}, no hook')
+            return ds
+        return self.dataset.post_xarray_open_dataset_hook(ds, *args, **kwargs)
