@@ -33,9 +33,15 @@ def test_datetime():
         "era5-temperature", domain="france", period=(1980,), time=12
     )
     data["1980-12-09 12:00"]
+    with pytest.raises(NotImplementedError):
+        data.sel(date="1980-12-09 12:00")
 
 
 def test_pandas_filter():
     data = cml.load_dataset("hurricane-database", "atlantic")
     irma = data.to_pandas(name="irma", year=2017)
     assert len(irma) == 66
+
+
+if __name__ == "__main__":
+    test_datetime()
